@@ -32,6 +32,7 @@ use app\util\SMTStatusDto;
 use app\util\SMTUtil;
 use app\view\SMTFileDownloadPage;
 use app\view\SMTTestRestApiPage;
+use app\admin\SMTOtuMode;
 
 /**
  * Service to clear and list alarms.
@@ -352,6 +353,10 @@ class SMTAlarmService extends SMTService implements SMTIService
         		$cleared = $alarmDto->isCleared();
         		$date = $alarmDto->getCurrentAlarmEvent()->getTime();
         		$hostName = $this->sendReceive( SMTOtuApi::CMD_get_otu_name );
+        		if ( !SMTOtuMode::isSmartOtuFamily() )
+        		{
+        		    $hostName = SMTUtil::convertToAscii($hostName );
+        		}
         		$linkName = $linkDto->getName();        		
         		$date = SMTUtil::getTimestamp( $date, $this->getContext() );
         		$this->getContext()->getDatabase()->close();
