@@ -13,7 +13,6 @@
 // *********************************************************
 namespace app\services\api;
 
-use app\services\security\SMTAccessControl;
 use app\services\SMTIService;
 use app\services\SMTService;
 use app\parser\SMTOtuApi;
@@ -603,7 +602,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 		}
 		catch ( \Exception $e )
 		{
-			$this->getContext()->getLogger()->traceException($ex);
+			$this->getContext()->getLogger()->traceException($e);
 			SMTHttpResponse::handleApiError( $this->getContext(), SMTRestException::BAD_REQUEST, SMTApiDto::FAILURE, 'Failed to retrieve guest user');
 		}
 		$this->getContext()->closeSession();
@@ -618,7 +617,7 @@ class SMTApiOtuService extends SMTService implements SMTIService
 	 * @access protected
 	 * @class SMTAccessControl {@requires install}
 	 */
-	function enableSmartOTUGuestCredential()
+	function enableSmartOTUGuestCredential($enable)
 	{
 		$this->checkApi();
 		
