@@ -50,6 +50,9 @@ use app\view\SMTTestRestApiPage;
 use app\services\SMTIService;
 use app\services\SMTService;
 use app\parser\SMTOtuApi;
+use app\serviceshelper\maintenance\SMTVpn;
+
+date_default_timezone_set("UTC"); 
 
 /**
  * Service to launch debug operations.
@@ -482,8 +485,8 @@ class SMTMaintenanceService extends SMTService implements SMTIService
         	$dto->setOtuSoftwareRelease( SMTSmartOtuSettings::getOtuVersion() );
         	$dto->setSmartOtuSoftwareRelease( SMTSmartOtuSettings::getSmartOtuVersion() );
         	        	 
-        	$timestampUTC = SMTUtil::getTimestampUTC( time(), $this->getContext()->getDatabase() );
-        	$dto->setCurrentTimeStampUTC( $timestampUTC );
+//         	$timestampUTC = SMTUtil::getTimestampUTC( time(), $this->getContext(), $this->getContext()->getDatabase() );
+        	$dto->setCurrentTimeStampUTC( time() );
         	$this->getContext()->getDatabase()->close();
     	}
     	catch( \Exception $e )
@@ -669,6 +672,83 @@ class SMTMaintenanceService extends SMTService implements SMTIService
     	return $dto->getJsonData();
     }
     
+    /**
+     * Request to retrieve the VPN file name
+     *
+     * @url GET /system/vpn
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function getVpnFile()
+    {        
+        try
+        {
+            $vpn = new SMTVpn();
+            $vpn->setContext($this->getContext());
+            $vpnDto = $vpn->retrieveVpn();
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+        return $vpnDto->getJsonData();
+    }
+    
+    /**
+     * Request to delete the VPN file name
+     *
+     * @url DELETE /system/vpn
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function deleteVpnFile()
+    {
+        if ( !SMTLicence::isVpnOption($this->getContext()) )
+        {
+            throw new SMTIOException(SMTIOException::INVALID_LICENSE);
+        }
+
+        try
+        {            
+            $vpn = new SMTVpn();
+            $vpn->setContext($this->getContext());
+            $vpn->deleteVpn();
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+    }
+    
+    /**
+     * Request to delete the VPN file name
+     *
+     * @url PUT /system/vpn
+     *
+     * @access protected
+     * @class SMTAccessControl {@requires user}
+     */
+    function applyVpnFile()
+    {
+        if ( !SMTLicence::isVpnOption($this->getContext()) )
+        {
+            throw new SMTIOException(SMTIOException::INVALID_LICENSE);
+        }
+    
+        try
+        {
+            $vpn = new SMTVpn();
+            $vpn->setContext($this->getContext());
+            $vpn->applyVpn();
+        }
+        catch ( \Exception $e )
+        {
+            $this->handleException($e);
+        }
+    }
+    
     /**
      * Start the upgrade of the OTU file system
      *
@@ -897,6 +977,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
     	{
     		$backupName = SMTOtuBackupRestore::getCurrentBackupName();
     		$backupFullPath = SMTOtuBackupRestore::checkBackupFileName( $backupName );
+    		$backupNameDto = SMTOtuBackupRestore::getLastAvailableBackupNameDto();
     		
     		if ( $backupFullPath != NULL )
     		{
@@ -1126,6 +1207,48 @@ class SMTMaintenanceService extends SMTService implements SMTIService
         	$this->getContext()->getHttpResponse()->send( $page );
         }
     }    
+    
+    /**
+     *
+     * @url GET /test/vpn/delete
+     */
+    function testDeleteVpn()
+    {
+        if ( SMTSmartOtuSettings::isDebugMode() )
+        {
+            $url = '/maintenance/system/vpn';
+            $page = new SMTTestRestApiPage($url, null, 'DELETE');
+            $this->getContext()->getHttpResponse()->send( $page );
+        }
+    }
+    
+    /**
+     *
+     * @url GET /test/vpn/apply
+     */
+    function testApplyVpn()
+    {
+        if ( SMTSmartOtuSettings::isDebugMode() )
+        {
+            $url = '/maintenance/system/vpn';
+            $page = new SMTTestRestApiPage($url, null, 'PUT');
+            $this->getContext()->getHttpResponse()->send( $page );
+        }
+    }
+    
+    /**
+     *
+     * @url GET /test/vpn/file
+     */
+    function testVpn()
+    {
+        if ( SMTSmartOtuSettings::isDebugMode() )
+        {
+            $url = '/maintenance/system/vpn';
+            $page = new SMTTestRestApiPage($url, null, 'GET');
+            $this->getContext()->getHttpResponse()->send( $page );
+        }
+    }
 }
 
 ?>
\ No newline at end of file
