@@ -48,6 +48,7 @@ use app\admin\SMTAuthenticationException;
 use app\util\SMTUtil;
 use app\serviceshelper\maintenance\SMTLicence;
 use app\services\maintenance\SMTLicenseListDto;
+use app\admin\SMTOtuMode;
 
 
 /**
@@ -290,6 +291,11 @@ class SMTSecurityService extends SMTService implements SMTIService
 	    try
 	    {
 	    	$name= $this->sendReceive( SMTOtuApi::CMD_get_otu_name);
+	    	if ( !SMTOtuMode::isSmartOtuFamily() )
+	    	{
+	    	    $name = SMTUtil::convertToAscii($name );
+	    	}
+
 	    	$init->setName($name);
 	    }
 	    catch ( \Exception $e )
