@@ -27,6 +27,7 @@ use app\services\SMTService;
 use app\parser\SMTOtuApi;
 use app\admin\SMTOtuType;
 use app\admin\SMTOtuMode;
+use app\util\SMTUtil;
 
 /**
  * Service to setup the OTU features (ethernet, modules, switches, Email, SNMP) and display its configuration.
@@ -122,6 +123,10 @@ class SMTEthernetService extends SMTService implements SMTIService
     	try
     	{
     		$name= $this->sendReceive( SMTOtuApi::CMD_get_otu_name);
+    		if ( !SMTOtuMode::isSmartOtuFamily() )
+    		{
+    		    $name = SMTUtil::convertToAscii($name );
+    		}
     	}
     	catch ( \Exception $e )
     	{
