@@ -41,6 +41,12 @@ class SMTAlarmSpecificProblemCode
     const OTU_OPT_ALARM_NON_REFLECTIVE_FAILURE_CODE="NON_REFLECTIVE";//1080;
     const OTU_OPT_ALARM_THRESHOLD_LEVEL_EXCEEDED_CODE="LEVEL";//1090;
     const OTU_OPT_ALARM_CONNECTOR_CODE="CONNECTOR";//1095;
+    const OTU_OPT_ALARM_SPLICE_BREAK =                 "SPLICE_BREAK";
+    const OTU_OPT_ALARM_CONNECTOR_BREAK =              "CONNECTOR_BREAK";
+    const OTU_OPT_ALARM_ATTENUATION_FIBER_BREAK =      "FIBER_BREAK";
+    const OTU_OPT_ALARM_SPLICE_ATTENUATION =           "SPLICE_ATTENUATION";
+    const OTU_OPT_ALARM_CONNECTOR_ATTENUATION =        "CONNECTOR_ATTENUATION";
+    const OTU_OPT_ALARM_FIBER_ATTENUATION =            "FIBER_ATTENUATION";
     const OTU_OPT_ALARM_RAMAN_POWER_DETECTION_CODE="RAMAN_DETECTED_POWER";//1100;
     const OTU_OPT_ALARM_RAMAN_POWER_DECREASE_CODE="RAMAN_LOW_POWER";//1110;
     const OTU_OPT_ALARM_INCOHERENCE_PROBLEM_WITH_RAMAN_ACQUISITION_MODE_CODE="RAMAN_INCOHERENCE";//1120;    
@@ -90,6 +96,12 @@ array( self::OTU_OPT_ALARM_UNKNOW_ALARM_CODE=>UNKNOW_ALARM,
        self::OTU_OPT_ALARM_NON_REFLECTIVE_FAILURE_CODE=>NON_REFLECTIVE_FAILURE,
        self::OTU_OPT_ALARM_THRESHOLD_LEVEL_EXCEEDED_CODE=>THRESHOLD_LEVEL_EXCEEDED,
        self::OTU_OPT_ALARM_CONNECTOR_CODE=>CONNECTOR_FAILURE,
+       self::OTU_OPT_ALARM_SPLICE_BREAK=>SPLICE_BREAK,
+       self::OTU_OPT_ALARM_CONNECTOR_BREAK=>CONNECTOR_BREAK,
+       self::OTU_OPT_ALARM_ATTENUATION_FIBER_BREAK=>FIBER_BREAK,
+       self::OTU_OPT_ALARM_SPLICE_ATTENUATION=>SPLICE_ATTENUATION,
+       self::OTU_OPT_ALARM_CONNECTOR_ATTENUATION=>CONNECTOR_ATTENUATION,
+       self::OTU_OPT_ALARM_FIBER_ATTENUATION=>FIBER_ATTENUATION,
        self::OTU_OPT_ALARM_RAMAN_POWER_DETECTION_CODE=>RAMAN_POWER_DETECTION,
        self::OTU_OPT_ALARM_RAMAN_POWER_DECREASE_CODE=>RAMAN_POWER_DECREASE,
        self::OTU_OPT_ALARM_INCOHERENCE_PROBLEM_WITH_RAMAN_ACQUISITION_MODE_CODE=>INCOHERENCE_PROBLEM_WITH_RAMAN_ACQUISITION_MODE,
@@ -188,14 +200,6 @@ public static function decodeOpticalAlarmSpecificProblem( $specificProblemCode,
     }
     else if ( $specificProblemCode === self::OTU_OPT_ALARM_CONNECTOR_CODE )
     {
-//     	if ( !$isCleared && ($severity == SMTAlarmSeverity::SEVERITY_CRITICAL) )
-//     	{
-//     		$specificProblemText = CONNECTOR_FIBER_CUT_FAILURE;
-//     	}
-//     	else 
-//     	{
-//     		$specificProblemText = CONNECTOR_ATTENUATION_FAILURE;
-//     	}
 		$specificProblemText = CONNECTOR_FAILURE;
     }
     else
