@@ -34,6 +34,8 @@ final class SMTLicenseList
 	const ULTRAFAST_MON='ULTRAFAST_MON';
 	const OTU_VPN='OTU_VPN';
 	const OTU_PAYG_PORT12='PAYG_PORT012';
+	const OTU_ONMSI_MONITORING='ONMSI_MONITORING';
+	const OTU_ONMSI_BUILD='ONMSI_BUILD';
 	
 	const OTU_OPTION_HIGH_SEC = 'HIGHSEC';
 	const OTU_OPTION_SSH_KEY_ACCESS = 'ACCESS';
@@ -48,7 +50,9 @@ final class SMTLicenseList
     const OTU_OPTION_ULTRAFAST_MON='ULTRAFAST_MON';
     const OTU_OPTION_VPN='OTU_VPN';
     const OTU_OPTION_PAYG_PORT12='PAYG_PORT012';
-
+    const OTU_OPTION_ONMSI_MONITORING='ONMSI_MON';
+    const OTU_OPTION_ONMSI_BUILD='ONMSI_BUILD';
+    
 	const ISU_OPTION_SAA_L2_MONITORING = 'SMART_ACCESS_L2';
 	
 // NOT VALID IN PHP 5.4 (OTU8Kv2)	
@@ -72,7 +76,9 @@ final class SMTLicenseList
 										self::OTU_OPTION_REST_API=>self::REST_API,
 	                                    self::OTU_OPTION_ULTRAFAST_MON=>self::ULTRAFAST_MON,
 	                                    self::OTU_OPTION_VPN=>self::OTU_VPN,
-	                                    self::OTU_OPTION_PAYG_PORT12=>self::OTU_PAYG_PORT12
+	                                    self::OTU_OPTION_PAYG_PORT12=>self::OTU_PAYG_PORT12,
+	                                    self::OTU_OPTION_ONMSI_MONITORING=>self::OTU_ONMSI_MONITORING,
+	                                    self::OTU_OPTION_ONMSI_BUILD=>self::OTU_ONMSI_BUILD
 	);
 	
 	static function getLicenseName( $scpiKey )
