@@ -1863,7 +1863,8 @@ class SMTLinkTest extends SMTServiceHelper
             {
                 if ( !SMTOtuMode::isSmartOtuFamily() )
                 {
-                    $name = utf8_encode(trim( $linkInfoArray[self::LINK_NAME_INDEX] ) );
+                    $name = SMTUtil::convertToAscii(trim( $linkInfoArray[self::LINK_NAME_INDEX] ) );
+                    //$name = utf8_encode(trim( $linkInfoArray[self::LINK_NAME_INDEX] ) );
                 }
                 else
                 {
