@@ -51,6 +51,12 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
         	$nbOsx = self::OSU_DISTRIBUTOR_INDEX -1 ;
         }
         
+        if ( $this->getSwitchDecoder( parent::GLOB)->hasPortsDistributorAtEnd() )
+        {
+            $result = $this->socket->sendReceive( SMTOtuApi::CMD_get_Nb_Port_Distributeur );
+            $this->getSwitchDecoder( parent::GLOB)->setPortDistributorNumber( intval( $result ) );
+        }
+        
         //retrieve OSU if needed: WARNING only retrieve OSU1 and OSU2 in simplified mode
         for ( $osuCount = 1; $osuCount <= $nbOsx; $osuCount++)
         {
@@ -84,7 +90,14 @@ class SMTMacroSwitchDet extends SMTMacroSwitch
             {
                 $this->setSwitchDecoder( parent::INTERNAL, $code );        
                 $this->serialNumber = $this->socket->sendReceive( sprintf( SMTOtuApi::CMD_switch_detect_SerialNum, SMTSwitchManager::MACRO_SWITCH_ID, parent::INTERNAL ) );
-            }
+            
+                $this->internalSwitchHasLicense = $this->isInternalSwitchWithLicence();
+                if ( $this->internalSwitchHasLicense )
+                {
+                    $this->internalSwitchOutPut = $this->getInternalSwitchTotalPorts();
+                }
+                
+            }            
         }
     }        
     
