@@ -35,7 +35,7 @@ class SMTSwitchDecoder
     private $switch_string = NULL;    
 
     /**
-     * OSU count per topologies excluding topologies M,N,O,P,Q,X,Y where the number of OSU is given directly in the configuration string
+     * OSU count per topologies excluding topologies M,N,O,P,Q,V,X,Y where the number of OSU is given directly in the configuration string
      */
     private $osu_Topologies = array("A"=>0,"B"=>1,"C"=>2,"D"=>1,"E"=>0,"F"=>0,"G"=>0,"H"=>0,"I"=>1,"J"=>1,"K"=>0,"L"=>4,"R"=>1, "T"=>2,"U"=>1);  
     
@@ -202,7 +202,7 @@ class SMTSwitchDecoder
     {
     	$molex = FALSE;
     	$customization = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::CUSTOMISATION, 1);
-    	if ( $customization == 'A' || $customization == 'B' || $customization == 'D' )
+    	if ( $customization == 'A' || $customization == 'B' || $customization == 'D' || $customization == 'F' || $customization == 'H')
     	{
     		$molex = TRUE;
     	}
@@ -218,7 +218,7 @@ class SMTSwitchDecoder
     {
     	$jdsu = FALSE;
     	$customization = substr($this->getSwitchEncodingString(), SMTSwitchDecoder::CUSTOMISATION, 1);
-    	if ( $customization == '3' || $customization == '4' ||$customization == '6' || $customization == '7' || $customization == '8' || $customization == '9' || $customization == 'C'  )
+    	if ( $customization == '3' || $customization == '4' ||$customization == '6' || $customization == '7' || $customization == '8' || $customization == '9' || $customization == 'C'  || $customization == 'E' || $customization == 'G' )
     	{
     		$jdsu= TRUE;
     	}
