@@ -53,9 +53,17 @@ class SMTSmartOtuThresholds
     const PEAK_POSITIVE_TO_MINOR_THRESHOLD = "PEAK_POSITIVE_TO_MINOR_THRESHOLD";
     const PEAK_POSITIVE_TO_MAJOR_THRESHOLD = "PEAK_POSITIVE_TO_MAJOR_THRESHOLD";
     
+    const TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD       = "TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD";
+    const TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD = "TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD";
+    const TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD = "TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD";
+    const TAPPING_POSITIVE_TO_MAJOR_THRESHOLD       = "TAPPING_POSITIVE_TO_MAJOR_THRESHOLD";
+    
     const MONITORING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT = "MONITORING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT";
     const DEFAULT_MONITORING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT = 6.0;
     
+    const TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT= "TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT";
+    const DEFAULT_TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT = 10.0;
+    
     const ATTENUATION_CRITICAL_THRESHOLD = "ATTENUATION_CRITICAL_THRESHOLD";
     const DEFAULT_ATTENUATION_CRITICAL_THRESHOLD = 6.0;
     
@@ -101,6 +109,14 @@ class SMTSmartOtuThresholds
     const DEFAULT_PEAK_POSITIVE_TO_MINOR_THRESHOLD = 2;
     const DEFAULT_PEAK_POSITIVE_TO_MAJOR_THRESHOLD = 4;
     
+    const DEFAULT_TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD = -0.1;
+    const DEFAULT_TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD = -0.08;
+    const DEFAULT_TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD = 0.08;
+    const DEFAULT_TAPPING_POSITIVE_TO_MAJOR_THRESHOLD = 0.1;
+    
+    const TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT = "TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT";
+    const DEFAULT_TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT = 0.02;
+    
     /**
      * Register the otu First Marker attenuation thresholds
      *
@@ -367,7 +383,114 @@ class SMTSmartOtuThresholds
     	}    	
     	
     	return $budgetVariationThresholds;
-    }            
+    }
+    
+    /**
+     * Register the otu tapping attenuation thresholds
+     *
+     * @param SMTOtuMonitoringTestThresholdDto $tappingThresholds The otu tapping attenuation thresholds.
+     *
+     */
+    public static function setDefaultTappingThresholds( SMTOtuMonitoringTestThresholdDto $tappingThresholds )
+    {
+    	
+    	self::saveDefaultTappingThresholdsInCache( $tappingThresholds);
+    	//save budget variation thresholds in settings file
+    	//save first marker attenuation thresholds in settings file
+    	SMTSmartOtuSettings::writeSettings( array(
+    			self::TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD => $tappingThresholds->getNegativeBackToNormalThreshold(),
+    			self::TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD => $tappingThresholds->getNegativeToMajorThreshold(),
+    			self::TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD => $tappingThresholds->getPositiveBackToNormalThreshold(),
+    			self::TAPPING_POSITIVE_TO_MAJOR_THRESHOLD => $tappingThresholds->getPositiveToMajorThreshold() ), self::SMARTOTU_THRESHOLDS_FILE );
+    }
+    
+    /**
+     * Save the otu tapping attenuation thresholds in cache
+     *
+     * @param SMTOtuMonitoringTestThresholdDto $tappingThresholds The tapping attenuation thresholds.
+     *
+     */
+    private static function saveDefaultTappingThresholdsInCache( SMTOtuMonitoringTestThresholdDto $tappingThresholds)
+    {
+    	if ( ( $settings = SMTSmartOtuSettingsCache::getSettingsFromCacheMemory() ) == NULL )
+    	{
+    		$settings = new SMTSmartOtuSettingsCache();
+    	}
+    	$settings->setDefaultTappingThresholds( $tappingThresholds);
+    	$settings->save();
+    }
+    
+    /**
+     * Get the tapping attenuation thresholds
+     *
+     * @return SMTOtuMonitoringTestThresholdDto The otu tapping attenuation thresholds.
+     */
+    public static function getDefaultTappingThresholds()
+    {
+    	$tappingThresholds = NULL;
+    	$settings = SMTSmartOtuSettingsCache::getSettingsFromCacheMemory();
+    	if ( $settings != NULL )
+    	{
+    		$tappingThresholds= $settings->getDefaultTappingThresholds();
+    	}
+    	
+    	//retrieve budget thresholds from ini file if it was not found in cache
+    	if ( $tappingThresholds== NULL )
+    	{
+    		$tappingThresholds= new SMTOtuMonitoringTestThresholdDto();
+    		$conf_array = parse_ini_file(self::SMARTOTU_THRESHOLDS_FILE);
+    		
+    		if( array_key_exists( self::TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD, $conf_array) )
+    		{
+    			$tappingThresholds->setNegativeBackToNormalThreshold( $conf_array[self::TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD] );
+    			$tappingThresholds->setNegativeBackToMinorThreshold( $conf_array[self::TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD]);
+    		}
+    		else
+    		{
+    			$tappingThresholds->setNegativeBackToNormalThreshold( self::DEFAULT_TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD);
+    			$tappingThresholds->setNegativeBackToMinorThreshold( self::DEFAULT_TAPPING_NEGATIVE_BACK_TO_NORMAL_THRESHOLD);
+    		}
+    		if( array_key_exists( self::TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD, $conf_array) )
+    		{
+    			$tappingThresholds->setNegativeToMajorThreshold( $conf_array[self::TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD] );
+    			$tappingThresholds->setNegativeToMinorThreshold( $conf_array[self::TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD] );
+    		}
+    		else
+    		{
+    			$tappingThresholds->setNegativeToMajorThreshold( self::DEFAULT_TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD);
+    			$tappingThresholds->setNegativeToMinorThreshold( self::DEFAULT_TAPPING_NEGATIVE_TO_MAJOR_THRESHOLD);
+    		}
+    		if( array_key_exists( self::TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD, $conf_array) )
+    		{
+    			$tappingThresholds->setPositiveBackToNormalThreshold( $conf_array[self::TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD] );
+    			$tappingThresholds->setPositiveBackToMinorThreshold( $conf_array[self::TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD] );
+    		}
+    		else
+    		{
+    			$tappingThresholds->setPositiveBackToNormalThreshold( self::DEFAULT_TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD);
+    			$tappingThresholds->setPositiveBackToMinorThreshold( self::DEFAULT_TAPPING_POSITIVE_BACK_TO_NORMAL_THRESHOLD);
+    		}
+    		if( array_key_exists( self::TAPPING_POSITIVE_TO_MAJOR_THRESHOLD, $conf_array) )
+    		{
+    			$tappingThresholds->setPositiveToMajorThreshold( $conf_array[self::TAPPING_POSITIVE_TO_MAJOR_THRESHOLD] );
+    			$tappingThresholds->setPositiveToMinorThreshold( $conf_array[self::TAPPING_POSITIVE_TO_MAJOR_THRESHOLD] );
+    		}
+    		else
+    		{
+    			$tappingThresholds->setPositiveToMajorThreshold( self::DEFAULT_TAPPING_POSITIVE_TO_MAJOR_THRESHOLD );
+    			$tappingThresholds->setPositiveToMinorThreshold( self::DEFAULT_TAPPING_POSITIVE_TO_MAJOR_THRESHOLD );
+    		}
+    		
+    		//minor threshold disabled by default
+    		$tappingThresholds->setMinorThresholdEnabled(FALSE);
+    		
+    		//save retrieved data in cache:
+    		self::saveDefaultTappingThresholdsInCache( $tappingThresholds);
+    	}
+    	
+    	return $tappingThresholds;
+    }
+    
     
     /**
      * Register the otu peak thresholds
@@ -525,7 +648,7 @@ class SMTSmartOtuThresholds
     	}
     	$settings->setMonitoringAcceptableNoiseMarginDbDefault( $monitoringAcceptableNoiseMarginDbDefault );
     	$settings->save();
-    }    
+    }
     
     /**
      * Get the Monitoring Acceptable Noise Margin (in Db) from cache or from ini file.
@@ -561,7 +684,71 @@ class SMTSmartOtuThresholds
     	}
     	
     	return floatval($monitoringAcceptableNoiseMarginDbDefault);
-    }    
+    }
+    
+    /**
+     * Register Tapping Acceptable Noise Margin (in Db)
+     *
+     * @param float $tappingAcceptableNoiseMarginDbDefault The Tapping Acceptable Noise Margin (in Db).
+     */
+    public static function setTappingAcceptableNoiseMarginDbDefault( $tappingAcceptableNoiseMarginDbDefault  )
+    {
+    	self::saveTappingAcceptableNoiseMarginDbDefaultInCache( $tappingAcceptableNoiseMarginDbDefault );
+    	//save TappingAcceptable Noise Margin in settings file
+    	SMTSmartOtuSettings::writeSettings( array( self::TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT=>$tappingAcceptableNoiseMarginDbDefault ) );
+    }
+    
+    /**
+     * Save Tapping Acceptable Noise Margin (in Db) in cache.
+     * Used to display that min noise level in trace viewer and to force user to set markers in traceviewer outside noise level.
+     *
+     * @param float $tappingAcceptableNoiseMarginDbDefault The Tapping Acceptable Noise Margin in Db.
+     */
+    private static function saveTappingAcceptableNoiseMarginDbDefaultInCache( $tappingAcceptableNoiseMarginDbDefault )
+    {
+    	if ( ( $settings = SMTSmartOtuSettingsCache::getSettingsFromCacheMemory() ) == NULL )
+    	{
+    		$settings = new SMTSmartOtuSettingsCache();
+    	}
+    	$settings->setTappingAcceptableNoiseMarginDbDefault( $tappingAcceptableNoiseMarginDbDefault);
+    	$settings->save();
+    }
+    
+    /**
+     * Get the Monitoring Acceptable Noise Margin (in Db) from cache or from ini file.
+     * Used to display that min noise level in trace viewer and to force user to set markers in traceviewer outside noise level.
+     *
+     * @return float Monitoring Acceptable Noise Margin (in Db)
+     */
+    public static function getTappingAcceptableNoiseMarginDbDefault()
+    {
+    	$tappingAcceptableNoiseMarginDbDefault = NULL;
+    	$settings = SMTSmartOtuSettingsCache::getSettingsFromCacheMemory();
+    	if ( $settings != NULL )
+    	{
+    		$tappingAcceptableNoiseMarginDbDefault = $settings->getTappingAcceptableNoiseMarginDbDefault();
+    	}
+    	
+    	//Retrieve Monitoring Acceptable Noise Margin (in Db) from ini file if it was not found in cache
+    	if ( $tappingAcceptableNoiseMarginDbDefault == NULL )
+    	{
+    		$conf_array = parse_ini_file(self::SMARTOTU_THRESHOLDS_FILE);
+    		
+    		if( array_key_exists( self::TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT, $conf_array) )
+    		{
+    			$tappingAcceptableNoiseMarginDbDefault = $conf_array[self::TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT];
+    		}
+    		else
+    		{
+    			$tappingAcceptableNoiseMarginDbDefault = self::DEFAULT_TAPPING_ACCEPTABLE_NOISE_MARGIN_DB_DEFAULT;
+    		}
+    		
+    		//save retrieved data in cache:
+    		self::saveTappingAcceptableNoiseMarginDbDefaultInCache( $tappingAcceptableNoiseMarginDbDefault );
+    	}
+    	
+    	return floatval($tappingAcceptableNoiseMarginDbDefault);
+    }
     
     /**
      * Register the attenuation critical threshold in Db
@@ -690,6 +877,69 @@ class SMTSmartOtuThresholds
     	return floatval($attenuationToBtoDeltaDbDefault);
     }
     
+    /**
+     * Register the delta between TO and BACK TO thresholds for tapping attenuation (in Db) in cache and in settings
+     *
+     * @param SMTOtuMonitoringTestThresholdDto $peakToBtoDeltaDbDefault The delta between TO and BACK TO thresholds for attenuation (in Db)
+     */
+    public static function setTappingToBtoDeltaDbDefault( $attenuationToBtoDeltaDbDefault  )
+    {
+    	self::saveTappingToBtoDeltaDbDefaultInCache( $attenuationToBtoDeltaDbDefault );
+    	//save budget variation thresholds in settings file
+    	//save first marker attenuation thresholds in settings file
+    	SMTSmartOtuSettings::writeSettings( array( self::TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT=>$attenuationToBtoDeltaDbDefault ) );
+    }
+    
+    /**
+     * Save the delta between TO and BACK TO thresholds for tapping attenuation (in Db) in cache.
+     *
+     * @param int $attenuationToBtoDeltaDbDefault The delta between TO and BACK TO thresholds for attenuation (in Db)
+     *
+     */
+    private static function saveTappingToBtoDeltaDbDefaultInCache( $attenuationToBtoDeltaDbDefault )
+    {
+    	if ( ( $settings = SMTSmartOtuSettingsCache::getSettingsFromCacheMemory() ) == NULL )
+    	{
+    		$settings = new SMTSmartOtuSettingsCache();
+    	}
+    	$settings->setTappingToBtoDeltaDbDefault( $attenuationToBtoDeltaDbDefault );
+    	$settings->save();
+    }
+    
+    /**
+     * Get the delta between TO and BACK TO thresholds for tapping attenuation (in Db) from cache or from ini file.
+     *
+     * @return The delta between TO and BACK TO thresholds for attenuation (in Db)
+     */
+    public static function getTappingToBtoDeltaDbDefault()
+    {
+    	$attenuationToBtoDeltaDbDefault = NULL;
+    	$settings = SMTSmartOtuSettingsCache::getSettingsFromCacheMemory();
+    	if ( $settings != NULL )
+    	{
+    		$attenuationToBtoDeltaDbDefault = $settings->getTappingToBtoDeltaDbDefault();
+    	}
+    	
+    	//Retrieve the delta between TO and BACK TO thresholds for attenuation (in Db) from ini file if it was not found in cache
+    	if ( $attenuationToBtoDeltaDbDefault == NULL )
+    	{
+    		$conf_array = parse_ini_file(self::SMARTOTU_THRESHOLDS_FILE);
+    		
+    		if( array_key_exists( self::TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT, $conf_array) )
+    		{
+    			$attenuationToBtoDeltaDbDefault = $conf_array[self::TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT];
+    		}
+    		else
+    		{
+    			$attenuationToBtoDeltaDbDefault = self::DEFAULT_TAPPING_TO_AND_BACK_TO_DELTA_DB_DEFAULT;
+    		}
+    		
+    		//save retrieved data in cache:
+    		self::saveTappingToBtoDeltaDbDefaultInCache( $attenuationToBtoDeltaDbDefault );
+    	}
+    	
+    	return floatval($attenuationToBtoDeltaDbDefault);
+    }
     
     /**
      * Register the delta between TO and BACK TO thresholds for peak (in Db) in cache and in settings
