@@ -1,7 +1,7 @@
 #!/bin/bash
 
 usage () {
-        echo "usage:  $0 <<file_path>> <<[ssl_cert, ssl_chain-cert, ssl_key, license] >>"
+        echo "usage:  $0 <<file_path>> <<[ssl_cert, ssl_chain-cert, ssl_key, license, vpn] >>"
         exit 1
 }
 
@@ -23,6 +23,11 @@ if [[ -s "$1" ]]; then
       license)
       file="/acterna/user/harddisk/Licence.lic" ;;
                
+      vpn)
+      fileName=`awk '/Subject: CN=/{print $2}' FS='=' "$1" | cut -f1 -d "."`
+      file="/etc/openvpn/$fileName.ovpn"
+      rm /etc/openvpn/* ;;
+               
       *)
       echo "bad option: $2"
       usage ;;
