@@ -1,6 +1,6 @@
-from jdsu.evm import *
-from jdsu.diag import *
-from jdsu.evm import *
+from viavi.evm import *
+from viavi.diag import *
+from viavi.evm import *
 from time import time, sleep
 from jdsu.mts.flashutils import install_release, install_pmulti
 from jdsu.mts.blockutils import get_block_devices
